@@ -142,3 +142,6 @@ LearnerClassifCVGlmnet = R6Class("LearnerClassifCVGlmnet",
     }
   )
 )
+
+#' @include aaa.R
+learners[["classif.cv_glmnet"]] = LearnerClassifCVGlmnet
