@@ -152,3 +152,6 @@ LearnerClassifGlmnet = R6Class("LearnerClassifGlmnet",
     }
   )
 )
+
+#' @include aaa.R
+learners[["classif.glmnet"]] = LearnerClassifGlmnet
