@@ -64,3 +64,6 @@ LearnerClassifNaiveBayes = R6Class("LearnerClassifNaiveBayes",
     }
   )
 )
+
+#' @include aaa.R
+learners[["classif.naive_bayes"]] = LearnerClassifNaiveBayes
