@@ -72,3 +72,6 @@ LearnerClassifQDA = R6Class("LearnerClassifQDA",
     }
   )
 )
+
+#' @include aaa.R
+learners[["classif.qda"]] = LearnerClassifQDA
