@@ -85,3 +85,6 @@ LearnerRegrKKNN = R6Class("LearnerRegrKKNN",
     }
   )
 )
+
+#' @include aaa.R
+learners[["regr.kknn"]] = LearnerRegrKKNN
