@@ -126,3 +126,6 @@ LearnerRegrKM = R6Class("LearnerRegrKM",
     }
   )
 )
+
+#' @include aaa.R
+learners[["regr.km"]] = LearnerRegrKM
